@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "selected-window-accent-mode" "0.6.0"
+(define-package "selected-window-accent-mode" "20251205.1215"
   "Accent Selected Window."
-  '((emacs              "25.1")
-    (visual-fill-column "0.0"))
+  '((emacs "28.1"))
   :url "https://github.com/captainflasmr/selected-window-accent-mode"
-  :commit "e83efa67c4a9d1935c657a15b4487102cb6655de"
-  :revdesc "e83efa67c4a9"
+  :commit "cfdcf242e2967c131ac01da6565d70a367e10320"
+  :revdesc "cfdcf242e296"
   :keywords '("convenience")
   :authors '(("James Dyer" . "captainflasmr@gmail.com"))
   :maintainers '(("James Dyer" . "captainflasmr@gmail.com")))
